<?php

/**
 * @file
 * Administrative functions to configure GoogleChat.
 */

/**
 * Callback for admin/settings/googlechat.
 */
function googlechat_settings_form() {
  $form = array();
  $form['googlechat_notification_sound'] = array(
    '#type' => 'select',
    '#title' => t('Notification Sound'),
    '#description' => t('Play a sound notification when new chat messages arrive'),
    '#options' => array(1 => 'Yes', 2 => 'No'),
    '#default_value' => variable_get('googlechat_notification_sound', 1),
  );
  $form['googlechat_enable_emoticons'] = array(
    '#type' => 'select',
    '#title' => t('Enable Emoticons'),
    '#description' => t('When an emoticon is sent :-) it will automatically animate.'),
    '#options' => array(1 => 'Yes', 2 => 'No'),
    '#default_value' => variable_get('googlechat_enable_emoticons', 1),
  );
  $intervals = array(30, 60, 120, 180, 300, 600, 900, 1800, 2700, 3600);
  $list_count = array(0 => 'unlimited', 5 => 5, 10 => 10, 15 => 15, 30 => 30, 50 => 50, 75 => 75, 100 => 100);
  $period = drupal_map_assoc($intervals, 'format_interval');
  $form['googlechat_seconds_online'] = array(
    '#type' => 'select',
    '#title' => t('User activity'),
    '#default_value' => variable_get('googlechat_seconds_online', 900),
    '#options' => $period,
    '#description' => t('A user is considered online for this long after they have last viewed a page.'
    ));
  $form['googlechat_max_list_count'] = array(
    '#type' => 'select',
    '#title' => t('User list length'),
    '#default_value' => variable_get('googlechat_block_max_list_count', 10),
    '#options' => drupal_map_assoc($list_count),
    '#description' => t('Maximum number of currently online users to display.'
    ));
  $form['googlechat_buddylist_control_list'] = array(
    '#type' => 'fieldset',
    '#title' => t('GoogleChat Buddy List Control'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['googlechat_buddylist_control_list']['googlechat_rel'] = array(
    '#type' => 'radios',
    '#title' => t('Relationship method'),
    '#default_value' => variable_get('googlechat_rel', 0),
    '#options' => array(
      GOOGLECHAT_REL_ALL => t('All authenticated users'),
    ),
    '#description' => t('This determines the method for creating the chat buddylist.'),
  );
  if (module_exists('flag_friend')) {
    $form['googlechat_buddylist_control_list']['googlechat_rel']['#options'][GOOGLECHAT_REL_FF] = t('Flag Friend module');
  }
  if (module_exists('user_relationships')) {
    $form['googlechat_buddylist_control_list']['googlechat_rel']['#options'][GOOGLECHAT_REL_UR] = t('User Relationship module');
  }
  if (module_exists('og')) {
    $form['googlechat_buddylist_control_list']['googlechat_rel']['#options'][GOOGLECHAT_REL_OG] = t('Organic Groups module');
  }
  return system_settings_form($form);
}
